@@ -17,7 +17,7 @@
 #include <KIO/Global>
 #include <KUrlRequester>
 
-#include <libkomparediff2/diffsettings.h>
+#include <KompareDiff2/DiffSettings>
 
 KompareSaveOptionsWidget::KompareSaveOptionsWidget(const QString& source, const QString& destination,
                                                    DiffSettings* settings, QWidget* parent)
@@ -213,3 +213,5 @@ void KompareSaveOptionsWidget::saveOptions()
     m_settings->m_format = static_cast<Kompare::Format>(m_FormatBG->checkedId());
 
 }
+
+#include "moc_komparesaveoptionswidget.cpp"
